@@ -1,7 +1,7 @@
 // padthv1widget_filt.cpp
 //
 /****************************************************************************
-   Copyright (C) 2012-2020, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2012-2021, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -26,7 +26,7 @@
 #include <QMouseEvent>
 #include <QWheelEvent>
 
-#include <math.h>
+#include <cmath>
 
 
 // Safe value capping.
